@@ -19,26 +19,24 @@
 #    at /usr/share/common-licenses/GPL
 ####################################################################################
 
-
 tar -xzvf rosetta-desktopguide.tar.gz
 rm rosetta-desktopguide/desktopguide.pot
-for x in rosetta-desktopguide/*; do
+mv rosetta-desktopguide po
+rm rosetta-desktopguide.tar.gz
+
+for x in po/*; do
 	y=$(basename ${x} .po)
 	echo ${y}
 	mkdir -p ${y}
-	xml2po -e -p ${x} C/desktopguide.xml >${y}/desktopguide.xml
-	xml2po -e -p ${x} C/getting-started.xml >${y}/getting-started.xml
-	xml2po -e -p ${x} C/add-applications.xml >${y}/add-applications.xml
-	xml2po -e -p ${x} C/getting-help.xml >${y}/getting-help.xml
-	xml2po -e -p ${x} C/bookinfo.xml >${y}/bookinfo.xml
-	xml2po -e -p ${x} C/preface.xml >${y}/preface.xml
-	xml2po -e -p ${x} C/desktopguide-C.omf >${y}/desktopguide-${y}.omf
-	xml2po -e -p ${x} C/config-system.xml >${y}/config-system.xml
-	xml2po -e -p ${x} C/common-tasks.xml >${y}/common-tasks.xml
-	../../validate.sh ${y}/desktopguide.xml
+	for i in C/*xml; do
+		j=$(basename ${i} C/)
+		echo ${j}
+		xml2po -k -p ${x} C/${j} | replace-doctype-with.py C/${j} >${y}/${j}
+	done
+	xml2po -k -p ${x} C/desktopguide-C.omf >${y}/desktopguide-${y}.omf
 	sed -i -e s@\"C\"@\"${y}\"@g -e s@C/@${y}/@g ${y}/desktopguide-${y}.omf
+	../../validate.sh ${y}/desktopguide.xml
 
 done
 
-rm -rf rosetta-desktopguide*
 rm .xml2po.mo
